==> logger_36-2025.4-py3-none-any.whl: logger_36/exception.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2023
SEE COPYRIGHT NOTICE BELOW
"""

import sys as sstm
import tempfile as tmpf
import traceback as tcbk
import types as t
from pathlib import Path as path_t

_ORIGINAL_EXCEPTION_HANDLER = sstm.excepthook


def OverrideExceptionFormat() -> None:
    """"""
    sstm.excepthook = _HandleException


def ResetExceptionFormat() -> None:
    """"""
    sstm.excepthook = _ORIGINAL_EXCEPTION_HANDLER


def _HandleException(
    stripe: type[Exception], exception: Exception, trace: t.TracebackType, /
) -> None:
    """"""
    while trace.tb_next is not None:
        trace = trace.tb_next
    frame = trace.tb_frame
    module = frame.f_code.co_filename
    function = frame.f_code.co_name
    line = frame.f_lineno

    home = str(path_t.home())
    if module.startswith(home):
        module = "~" + module[home.__len__():]

    message = str(exception)
    if message.__len__() > 0:
        message = f"    {message}\n"

    document = tmpf.NamedTemporaryFile(delete=False)

    print(
        f"{stripe.__name__}\n"
        f"    {module}.{function}@{line}\n"
        f"{message}    Full report at: {document.name}",
        file=sstm.stderr,
    )

    lines = tcbk.format_exception(exception)
    message = "".join(lines)

    document.write(message.encode())
    document.close()


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""

==> logger_36-2025.5-py3-none-any.whl: logger_36/exception.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2023
SEE COPYRIGHT NOTICE BELOW
"""

import sys as s
import tempfile as tmpf
import traceback as tcbk
import types as t
from pathlib import Path as path_t

_ORIGINAL_EXCEPTION_HANDLER = s.excepthook


def OverrideExceptionFormat() -> None:
    """"""
    s.excepthook = _HandleException


def ResetExceptionFormat() -> None:
    """"""
    s.excepthook = _ORIGINAL_EXCEPTION_HANDLER


def _HandleException(
    stripe: type[Exception], exception: Exception, trace: t.TracebackType, /
) -> None:
    """"""
    while trace.tb_next is not None:
        trace = trace.tb_next
    frame = trace.tb_frame
    module = frame.f_code.co_filename
    function = frame.f_code.co_name
    line = frame.f_lineno

    home = str(path_t.home())
    if module.startswith(home):
        module = "~" + module[home.__len__() :]

    message = str(exception)
    if message.__len__() > 0:
        message = f"    {message}\n"

    document = tmpf.NamedTemporaryFile(delete=False)

    print(
        f"{stripe.__name__}\n"
        f"    {module}.{function}@{line}\n"
        f"{message}    Full report at: {document.name}",
        file=s.stderr,
    )

    lines = tcbk.format_exception(exception)
    message = "".join(lines)

    document.write(message.encode())
    document.close()


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""
